黑客帝国 (豆瓣)
Description: 黑客帝国电影简介和剧情介绍,黑客帝国影评、图片、预告片、影讯、论坛、在线购票
Keywords: 黑客帝国,The Matrix,黑客帝国影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.55豆瓣电影Top250

# 黑客帝国 The Matrix (1999)

导演: 莉莉·沃卓斯基 / 拉娜·沃卓斯基
编剧: 莉莉·沃卓斯基 / 拉娜·沃卓斯基
主演: 基努·里维斯 / 劳伦斯·菲什伯恩 / 凯瑞-安·莫斯 / 雨果·维文 / 格洛丽亚·福斯特 / 乔·潘托里亚诺 / 马库斯·钟 / 朱利安·阿拉汗加 / 马特·多兰 / 贝琳达·麦克洛里 / 安东尼雷派克 / 罗伯特·泰勒 / 阿达·尼科德莫 / 罗温·维特 / 塔玛拉·布朗 / 纳塔莉·特珍 / 比尔·扬 / 克里斯·斯科特 / 纳许·埃哲顿
类型: 动作 / 科幻
制片国家/地区: 美国
语言: 英语
上映日期: 2000-01-14(中国大陆) / 1999-03-31(美国)
片长: 136分钟
又名: 22世纪杀人网络(港) / 廿二世纪杀人网络(港) / 骇客任务(台) / 骇客帝国
IMDb: tt0133093
豆瓣评分
引用
9.1
798218人评价
5星
62.5%
4星
30.3%
3星
6.5%
2星
0.5%
1星
0.1%
好于 99% 科幻片
好于 99% 动作片
想看 看过
评价:
推荐

## 黑客帝国的剧情简介 · · · · · ·

不久的将来，网络黑客尼奥（基奴李维斯 饰）对这个看似正常的现实世界产生了怀疑。他结识了黑客崔妮蒂（凯莉·安·摩丝 饰），并见到了黑客组织的首领墨菲斯（劳伦斯·菲什伯恩 饰）。墨菲斯告诉他，现实世界其实是由一个名叫“母体”的计算机人工智能系统控制，人们就像他们饲养的动物，没有自由和思想，而尼奥就是能够拯救人类的救世主。
可是，救赎之路从来都不会一帆风顺，到底哪里才是真实的世界？如何才能打败那些超人一样的特勤？尼奥是不是人类的希望？这是黑客的帝国，程序和代码欢迎大家的到来。. ©豆瓣

## 黑客帝国的演职员 · · · · · · ( 全部 35 )

- 莉莉·沃卓斯基 导演
- 拉娜·沃卓斯基 导演
- 基努·里维斯 饰 Neo
- 劳伦斯·菲什伯恩 饰 Morpheus
- 凯瑞-安·莫斯 饰 Trinity
- 雨果·维文 饰 Agent Smith

## 黑客帝国的视频和图片 · · · · · · ( 预告片4 | 添加视频评论 | 图片1372 · 添加 )

## 黑客帝国的获奖情况 · · · · · · ( 全部 )

- 第72届奥斯卡金像奖
- 最佳剪辑
- 扎克·斯伯格

- 第53届英国电影学院奖
- 电影奖 最佳摄影(提名)
- 比尔·波普

- 第23届日本电影学院奖
- 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  黑客帝国3：矩阵革命

  终结者2：审判日

  阿凡达

  盗梦空间

  这个男人来自地球

  变形金刚

  源代码

  E.T.外星人

  2001太空漫游

  钢铁侠

我要写短评

## 黑客帝国的短评 · · · · · · ( 全部 132303 条 )

热门 / 最新 / 好友

### 5719 有用 米姐起飞 看过 2012-01-20 11:44:36

果真没让我失望~频频赞叹1999年人家的思维人家的意识 而咱都2012了还是爱构思古装穿越剧。。。

### 2097 有用 朝暮雪 看过 2012-08-18 01:26:16

有没有可能整个世界都是电脑模拟出来的，我们以及我们周围的一切也只是电脑中的一串代码？ “你和所有人一样，生来就是奴隶，你生在一座自己感知不到的监狱” 这种猜想已经足够震撼人心，但《黑客帝国》的深度还不止于此，它还在这个基础上提出了新的问题： 你会选择蓝药丸还是红药丸？ 是选择美好的虚幻还是残酷的现实？ 表面上好像很好选，其实比我们想象中困难得多。 一边是未来的末日世界，被饥饿和寒冷所摧残，还要面临... 有没有可能整个世界都是电脑模拟出来的，我们以及我们周围的一切也只是电脑中的一串代码？ “你和所有人一样，生来就是奴隶，你生在一座自己感知不到的监狱” 这种猜想已经足够震撼人心，但《黑客帝国》的深度还不止于此，它还在这个基础上提出了新的问题： 你会选择蓝药丸还是红药丸？ 是选择美好的虚幻还是残酷的现实？ 表面上好像很好选，其实比我们想象中困难得多。 一边是未来的末日世界，被饥饿和寒冷所摧残，还要面临被机器人追杀的危险； 一边是温馨和平的年代，有蓝天白云、良辰美景，甚至还有成为成功人士的机会。 的确，所有人都知道梦境再美好也只是梦境。 但塞弗就是愿意为了区区一个梦境出卖所有人。 假如我们真的逃出矩阵，体验到现实的残酷，也许我们会做出和塞弗相同的选择。 正如当你做了美梦的时候，你宁愿继续留在梦里，不愿醒来。 (展开)

### 3076 有用 麻木粮姜 看过 2008-04-15 21:49:44

其中的哲学影响我的哲学道路

### 1476 有用 長閑 看过 2013-01-28 10:51:37

黑格尔的异化理论，事物发展到一定阶段会异化出与之相对的异己，异己的发展会最终替代本体，人发明机器，最终被机器所替代。

### 1543 有用 艾小柯 看过 2006-06-21 01:51:50

新的哲学，开创动作片之先河

> 更多短评 132303条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 黑客帝国的影评 · · · · · · ( 全部 1277 条 )

热门 / 最新 / 好友
|53/V> 2006-12-02 18:09:12

## 多年后重看，发现第二第三部以前完全没看懂

实际上，Zion同样是一个虚拟的系统，我将它称为Zion世界或Zion系统。而不是什么real world。仔细研究Neo和创造者Architect的对话，你会发现导演已经把这个事实交代的清清楚楚了。 Neo正是从单手挡乌贼开始怀疑Zion世界的真实性的，所以他见到先知Oracle的第一个问题就问挡乌贼... (展开)
5216 261 596回应 收起
安然 2008-07-07 16:08:29

## 【转经典评论】杜车别 评 黑客帝国

这篇影评可能有剧透

矩阵系列电影本质上讲的是新型智能生命进化的过程，讲述人类是如何被最终扔入文明的垃圾箱的过程，如何被榨干最后一点利用价值的过程。 首先要纠正一些人的错误看法，他们居然一直认为矩阵中，人类是被作为能源来被利用的。真是可笑，机器文明什么能源不可以利用啊，核能，化... (展开)
1419 107 241回应 收起
稻草超人 2006-01-14 01:35:19

## ***黑客帝国的来信*** （无厘头VS哲学~~~）

这篇影评可能有剧透

哥们： 我是尼奥，没吓着你吧！ 我给你的信没别的意思，就是想告诉你一些别人忽略了的细节…… ..新生.. 我起先当黑客主要是因为失眠的厉害，真没事干了。一不留神，嘿，我说世界第二，还真没人敢当第一。后来冒出了个叫Trinity的朋友，分分钟入侵政府各... (展开)
1032 119 147回应 收起
mado1983 2006-07-23 00:01:23

## 绝对意识主义

我从来都不是个唯物主义者，虽然多年来被国内的教育体制灌输着“世界是物质的，物质世界是可以认知的”的理论，我仍然相信宇宙茫茫，千奇百怪，有很多事不能用物质论的观点来解释；而思想，有时甚至可以超越肉体，完成一些普通人不能完成的举动。中学课本上那些对意识世界毫无... (展开)
864 237 233回应 收起
Neo 2019-03-30 13:41:02

## 《黑客帝国系列》之百遍观感I：终极解答

这篇影评可能有剧透

一直不想写关于《黑客帝国》的评论，实在是因为它在我心中的地位难以言说的崇高，从2001年第一次看第一部算起，至今已经18、9年了，三部曲与动画版看了不下百遍。清楚记得第一次看完时，年幼的我陷入了深深的自我怀疑：“这世界是真的吗？我是真的吗？”我小小的内心世界里波涛... (展开)
376 11 125回应 收起
physixfan 2011-04-25 12:01:09

## 再看《黑客帝国》三部曲：为什么人类应该选择留在Matrix里

（原作者 wlsk） 黑客帝国的剧情比较难懂，而且电影融入了大量哲学元素，如存在主义、结构主义、宿命论、虚无主义等等。解析剧情的帖子网上有不少，这里我想讨论的不是剧情，而是在假设读者熟悉电影的情况下说说为什么留在Matrix里才是一个合理的选择。 绝大部分人都是希... (展开)
410 55 98回应 收起
Peace 2011-11-27 12:02:19

## 《黑客帝国Ⅰ》中深刻的佛法义理 ZT

这篇影评可能有剧透

https://site.douban.com/widget/forum/1513667/discussion/40547131/ 电影"Matrix "《黑客帝国》，第二集于 2003 年上演，这部电影真的很难得，即使佛教界自己筹资，拍一部电影来介绍佛法，恐怕也很难比《黑客帝国》拍得更好。它从头到尾都没有佛学名相，也没有佛像和宗教人物... (展开)
356 14 47回应 收起
Stella_仓鼠 2007-09-26 00:04:23

## 自由，何谓自由？

我又恢复了周末熬夜看电影的“好”习惯。之所以要熬夜，是为了要等同宿舍的人都睡下，一片安静之后，可以拉上帘子，关了灯，如同自己的mini影院一样，抱着电脑看电影。优点显而易见：不容易受打扰、可以投入的看电影、也很享受……缺点就是，看了动作片之后，基本上就意味着你... (展开)
274 25 33回应 收起
百八十米 2011-12-20 16:17:26

## 宁财神，您别丢人了。

这篇影评可能有剧透

看到宁财神在骂《盗梦空间》,说太难看，理由是：用了一个小时解释设定，能不难看吗？接着他又说《黑客帝国》就很好看，特别的简单易懂。回想起，财神加入电影编剧圈后的《大笑江湖》等著名作品，我悟了，你丫原来是真不懂啊。 很多人说《盗梦空间》是一部高智商电影，其实不至... (展开)
123 30 33回应 收起

> 更多影评 1277篇

添加新讨论

## 讨论区 · · · · · ·

zy有吗？带字幕，一二部 | 来自Magic Bing | 2 回应 | 2022-11-22 20:07:26
哪里有片源 | 来自Vary | 1 回应 | 2022-11-22 19:32:37
黑客帝国为什么不让布拉德皮特演 | 来自随遇而安 |  | 2022-11-22 06:56:46
真心推荐 | 来自世人谓我恋长安 | 1 回应 | 2022-11-18 10:58:40
哪里有片源 | 来自Vary |  | 2022-11-18 10:56:47

> 去这部影片的讨论区（全部372条）

## 关于《黑客帝国》的问题 · · · · · · ( 全部40个 )

- “有一代系统只有欢乐没有痛苦，但是没过多久大家就相继死去”是哪里？ 6人回答
- 为什么要一定接电话才能离开matrix？ 5人回答

> 全部40个问题

## 以下片单推荐 · · · · · · ( 全部 )

## 谁在看这部电影 · · · · · ·

- momo
  1分钟前 看过
- 王小美滋滋
  7分钟前 看过
- 沉默是最好的
  7分钟前 看过

1328279人看过 / 252710人想看

订阅黑客帝国的评论:
feed: rss 2.0